#!/usr/bin/env node
"use strict";
var assert = require("assert");
var path = require("path");
var program = require("commander");
var file_util_1 = require("../lib/file-util");
var config_1 = require("../lib/config");
var generate_1 = require("../lib/generate");
// tslint:disable-next-line
var meta = require('../../package.json');
program
    .version(meta.version)
    .usage('<directory...>')
    .parse(process.argv);
if (program.args.length === 0) {
    program.help();
}
else {
    var patterns = program.args.map(function (arg) {
        return path.join(arg, '**/*.vue');
    });
    var root = path.resolve(detectDeepestRoot(program.args));
    var config = config_1.findAndReadConfig(root);
    var options = config ? config.options : {};
    generate_1.generate(file_util_1.globSync(patterns), options);
}
function detectDeepestRoot(pathNames) {
    assert(pathNames.length >= 1);
    var root = pathNames[0].split(path.sep);
    pathNames.slice(1).forEach(function (pathName) {
        var dirs = pathName.split(path.sep);
        dirs.forEach(function (dir, i) {
            if (root[i] !== dir) {
                root = root.slice(0, i);
            }
        });
    });
    return root.join(path.sep);
}
