"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
require("colors");
var path = require("path");
var language_service_1 = require("./language-service");
var file_util_1 = require("./file-util");
function generate(filenames, options) {
    var vueFiles = filenames
        .filter(function (file) { return /\.vue$/.test(file); })
        .map(function (file) { return path.resolve(file); });
    // Should not emit if some errors are occurred
    var service = new language_service_1.LanguageService(vueFiles, __assign({}, options, { noEmitOnError: true }));
    return Promise.all(vueFiles.map(function (file) {
        // .ts suffix is needed since the compiler skips compile
        // if the file name seems to be not supported types
        var dts = service.getDts(file + '.ts');
        var dtsPath = file + '.d.ts';
        if (dts.errors.length > 0) {
            logError(dtsPath, dts.errors);
            return;
        }
        if (dts.result === null)
            return;
        return file_util_1.writeFile(dtsPath, dts.result)
            .then(function () {
            logEmitted(dtsPath);
        });
    }));
}
exports.generate = generate;
function logEmitted(filePath) {
    console.log('Emitted: '.green + filePath);
}
function logError(filePath, messages) {
    var errors = [
        'Emit Failed: '.red + filePath
    ].concat(messages.map(function (m) { return '  ' + 'Error: '.red + m; }));
    console.error(errors.join('\n'));
}
