"use strict";
var ts = require("typescript");
var ts_file_map_1 = require("./ts-file-map");
var LanguageService = (function () {
    function LanguageService(rootFileNames, options) {
        var _this = this;
        this.options = options;
        this.files = new ts_file_map_1.TsFileMap();
        rootFileNames.forEach(function (file) {
            _this.files.registerFile(file);
        });
        var serviceHost = this.makeServiceHost(options);
        this.tsService = ts.createLanguageService(serviceHost, ts.createDocumentRegistry());
    }
    LanguageService.prototype.getDts = function (fileName) {
        // Unsupported files or not found
        if (!this.files.canEmit(fileName)) {
            return {
                result: null,
                errors: []
            };
        }
        var output = this.tsService.getEmitOutput(fileName, true);
        if (!output.emitSkipped) {
            var result = output.outputFiles
                .filter(function (file) { return /\.d\.ts$/.test(file.name); })[0].text;
            return {
                result: result,
                errors: []
            };
        }
        return {
            result: null,
            errors: this.collectErrorMessages(fileName)
        };
    };
    LanguageService.prototype.makeServiceHost = function (options) {
        var _this = this;
        return {
            getScriptFileNames: function () { return _this.files.fileNames; },
            getScriptVersion: function (fileName) { return _this.files.getVersion(fileName); },
            getScriptSnapshot: function (fileName) {
                var src = _this.files.getSrc(fileName);
                return src && ts.ScriptSnapshot.fromString(src);
            },
            getCurrentDirectory: function () { return process.cwd(); },
            getCompilationSettings: function () { return options; },
            getDefaultLibFileName: function (options) { return ts.getDefaultLibFilePath(options); }
        };
    };
    LanguageService.prototype.collectErrorMessages = function (fileName) {
        var allDiagnostics = this.tsService.getCompilerOptionsDiagnostics()
            .concat(this.tsService.getSyntacticDiagnostics(fileName))
            .concat(this.tsService.getSemanticDiagnostics(fileName));
        return allDiagnostics.map(function (diagnostic) {
            var message = ts.flattenDiagnosticMessageText(diagnostic.messageText, '\n');
            if (diagnostic.file) {
                var _a = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start), line = _a.line, character = _a.character;
                return "[" + (line + 1) + "," + (character + 1) + "] " + message;
            }
            return message;
        });
    };
    return LanguageService;
}());
exports.LanguageService = LanguageService;
