"use strict";
var vueCompiler = require("vue-template-compiler");
var file_util_1 = require("./file-util");
var TsFileMap = (function () {
    function TsFileMap() {
        this.files = {};
    }
    Object.defineProperty(TsFileMap.prototype, "fileNames", {
        get: function () {
            return Object.keys(this.files).filter(function (file) { return isSupportedFile(file); });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * If the file does not exists or it is unsupported type,
     * we does not try emit output or the compiler throws an error
     */
    TsFileMap.prototype.canEmit = function (fileName) {
        var file = this.files[fileName];
        return file != null && !!file.text;
    };
    TsFileMap.prototype.getSrc = function (fileName) {
        var file = this.files[fileName];
        // If it does not processed yet,
        // register it into map with returning file data
        if (!file) {
            file = this.registerFile(fileName);
        }
        return file && file.text;
    };
    TsFileMap.prototype.getVersion = function (fileName) {
        return this.files[fileName] && this.files[fileName].version.toString();
    };
    TsFileMap.prototype.registerFile = function (fileName) {
        var rawFileName = getRawFileName(fileName);
        var src = file_util_1.readFileSync(rawFileName);
        // If file is not exists
        if (src === undefined)
            return undefined;
        var file = {
            rawFileName: rawFileName,
            version: 0,
            text: src
        };
        if (!isVueFile(rawFileName)) {
            this.files[rawFileName] = file;
            return file;
        }
        // If it is .vue file, extract script part and check it is ts or not
        var script = vueCompiler.parseComponent(src, { pad: true }).script;
        if (script == null || script.lang !== 'ts') {
            return undefined;
        }
        file.text = script.content;
        // To ensure the compiler can process .vue file,
        // we need to add .ts suffix to file name
        this.files[rawFileName + '.ts'] = file;
        return file;
    };
    return TsFileMap;
}());
exports.TsFileMap = TsFileMap;
function isSupportedFile(fileName) {
    return /\.(vue|tsx?|jsx?)$/.test(fileName);
}
function isVueFile(fileName) {
    return /\.vue(?:\.ts)?$/.test(fileName);
}
// If fileName is already suffixed by `.ts` remove it
function getRawFileName(fileName) {
    if (/\.vue\.ts$/.test(fileName)) {
        return fileName.slice(0, -3);
    }
    return fileName;
}
